@@ -344,7 +344,7 @@ DROP TABLE IF EXISTS snmp_devices;
 CREATE TABLE snmp_devices(
 id INT NOT NULL AUTO_INCREMENT PRIMARY KEY,
 address VARCHAR(128) UNIQUE DEFAULT NULL,
-community_string VARCHAR(64) DEFAULT NULL,
+community_string VARCHAR(64) DEFAULT 'public',
 protocol_version INT DEFAULT 2,
 last_success DATETIME DEFAULT NULL,
 last_failure DATETIME DEFAULT NULL,
