@@ -10,13 +10,13 @@ INSERT INTO agents (name, dir_name, package_name, minimal_version, dev_type, sho
 INSERT INTO agent_device_type_map (agent_id, device_type_id) VALUES (1, 2), (2, 1), (3, 3), (4, 4), (1, 5);
 
 INSERT INTO agent_versions (dev_type, version_major, version_minor, version_patchlevel, actual) VALUES
-(1, 1, 1, 0, true),
-(2, 1, 1, 0, true),
-(3, 1, 1, 0, true),
-(4, 1, 1, 0, true);
+(1, 1, 4, 0, true),
+(2, 1, 4, 0, true),
+(3, 1, 4, 0, true),
+(4, 1, 4, 0, true);
 
 INSERT INTO product_versions (id, actual, version_major, version_minor, version_patchlevel, version_string, major, beta, notification, force_display, release_date, description) values 
-(1, true, 1, 3, 0, 'Afterparty 3 (Keeper BETA 3)', false, true, true, true, '2025-10-20',
+(1, true, 1, 4, 0, 'Afterparty 4 (Keeper BETA 4)', false, true, true, true, '2025-11-18',
 '<h5>Release notes</h5>'
 '<b>The release notes below are not completely relevant to the BETA version you are running, these are preparations for the Dwarfguard 2.0.0 Keeper version.</b>'
 '<h6>Server:</h6><ul>'
@@ -51,14 +51,14 @@ INSERT INTO product_versions (id, actual, version_major, version_minor, version_
 '<li></li>'
 '</ul>');
 
-INSERT INTO product_flags(id, version, description) values ('buildtag', 1, 'v1.2.0_BETA (+7)');
+INSERT INTO product_flags(id, version, description) values ('buildtag', 1, 'v1.3.0_BETA (+34)');
 INSERT INTO product_flags(id, version, description) values ('about_info', 1, 'Dwarfguard - Monitoring, Alerting, Management and Automation System
 
-Build tag: v1.2.0_BETA (+7)
-Build date: 2025_10_08__17_36_18
+Build tag: v1.3.0_BETA (+34)
+Build date: 2025_11_26__18_19_33
 
 Build components:
-(mamas): v1.2.0_BETA (+6)
-(mamasbig): v1.2.0_BETA (+1)
-(mamasweb): v1.2.0_BETA
-(mamasnotify): v1.2.0_BETA');
+(mamas): v1.3.0_BETA (+8)
+(mamasbig): v1.3.0_BETA (+1)
+(mamasweb): v1.3.0_BETA (+25)
+(mamasnotify): v1.3.0_BETA');
