@@ -19,6 +19,11 @@ install_build_12() {
 	return $?
 }
 
+install_build_13() {
+	install_build_12
+	return $?
+}
+
 # -----------------------  run/tests  -----------------------------
 
 install_run_11() {
@@ -41,6 +46,16 @@ install_run_12() {
 	return $?
 }
 
+install_run_13() {
+	apt-get -y install binutils apache2 mariadb-server slay python3 python3-mysqldb curl unzip sudo libapache2-mod-php php8.4 php8.4-mysql php8.4-mbstring php8.4-xml php8.4-intl php8.4-tokenizer php8.4-gd php8.4-imagick php8.4-curl php8.4-zip php8.4-bcmath mariadb-client rsync libjson-c5 libbsd0 libarchive13 sshpass libffi8 jq pipx dropbear-bin influxdb influxdb-client
+	res=$?
+	[ $res -eq 0 ] || return $res
+	systemctl enable apache2
+	systemctl start apache2
+	sleep 2
+	return $?
+}
+
 install_build() {
 	local deb_version=""
 	if [ -f "$deb_version_file" ] ; then
@@ -49,7 +64,7 @@ install_build() {
 			"11")
 				install_build_11
 				;;
-			"12")
+			"12"|"13")
 				install_build_12
 				;;
 			*)
@@ -73,6 +88,9 @@ install_run() {
 			"12")
 				install_run_12
 				;;
+			"13")
+				install_run_13
+				;;
 			*)
 				echo "This script does not support the version of Debian GNU/Linux that was detected ($deb_version). You may try to look inside the script ($0) for a package list or call the install_run_11 or install_run_12 functions manually." >&2
 				return 1
@@ -88,7 +106,7 @@ install_grafana() {
 	grafana_keyring_file="/etc/apt/keyrings/grafana.gpg"
 	grafana_apt_url="https://apt.grafana.com"
 	[ -f "$grafana_apt_conf" ] || {
-		apt-get install -y apt-transport-https software-properties-common wget || return 1
+		apt-get install -y apt-transport-https wget || return 1
 		mkdir -p /etc/apt/keyrings/ || return 1
 		wget -q -O - "$grafana_apt_url/gpg.key" | gpg --dearmor | sudo tee "${grafana_keyring_file}" > /dev/null || return 1
 		echo "deb [signed-by=$grafana_keyring_file] $grafana_apt_url stable main" | sudo tee -a "$grafana_apt_conf"
