@@ -346,9 +346,9 @@ def mdb_devicedata_waiting(devid):
 def get_agent_type(intype, maxtype=None):
     maxt = maxtype
     if maxtype is None:
-        maxt = Devtype.TENECT_GW
+        maxt = Devtype.TENECT_GW+1
     if intype not in devtypes or Devtype.ANYDEVICE == intype or intype == Devtype.MAXDEVICES:
-        return random.randrange(Devtype.ANYDEVICE+1, maxt)
+        return random.randrange(Devtype.ANYDEVICE+1, maxt+1)
     return intype
 
 def get_iccid():
@@ -393,6 +393,7 @@ def get_machid(devt = Devtype.ANYDEVICE):
         return m
     elif devt == Devtype.SNMPDEVICE:
         m = ".".join(str(random.randint(0, 255)) for _ in range(4))+';snmp;snmp;snmp'
+        return m
     else:
         raise Exception("Machine-ID generation not implemented for this device type:", str(devt))
 
