@@ -287,7 +287,7 @@ class DatatableQueryBuilder
 
         $query = $qb->getQuery();
         $query->setHydrationMode(Query::HYDRATE_ARRAY)->useQueryCache($this->useQueryCache);
-        \call_user_func_array([$query, 'useResultCache'], $this->useResultCacheArgs);
+        //\call_user_func_array([$query, 'useResultCache'], $this->useResultCacheArgs);
 
         return $query;
     }
@@ -306,7 +306,7 @@ class DatatableQueryBuilder
 
         $query = $qb->getQuery();
         $query->useQueryCache($this->useCountQueryCache);
-        \call_user_func_array([$query, 'useResultCache'], $this->useCountResultCacheArgs);
+        //\call_user_func_array([$query, 'useResultCache'], $this->useCountResultCacheArgs);
 
         return ! $qb->getDQLPart('groupBy')
             ? (int) $query->getSingleScalarResult()
