@@ -19,8 +19,8 @@ class UserEvent extends Event
     public const RESETTING = 'user.resetting';
     public const RESETTING_COMPLETE = 'user.resetting_complete';
 
-    private $response;
-    private $user;
+    private ?Response $response;
+    private UserInterface $user;
 
     public function __construct(UserInterface $user)
     {
