@@ -8,8 +8,11 @@ use App\Entity\AgentProfile\AgentProfile;
 use App\Entity\ConfigProfile\ConfigProfile;
 use App\Entity\Device\Device;
 use App\Entity\Device\DeviceOsVersion;
+use App\Entity\Device\DeviceType;
+use App\Repository\ConfigProfileRepository;
 use App\Repository\DeviceRepository;
 use App\Service\Api\AgentProfiles;
+use App\Service\Api\ConfigProfiles;
 use Doctrine\DBAL\ArrayParameterType;
 use Doctrine\DBAL\Connection;
 use Doctrine\DBAL\Exception;
@@ -21,6 +24,10 @@ use Symfony\Component\HttpFoundation\Request;
 use Symfony\Component\HttpFoundation\Response;
 use Symfony\Component\Routing\Annotation\Route;
 use App\Service\Api\Device as DeviceApi;
+use Symfony\Contracts\HttpClient\Exception\ClientExceptionInterface;
+use Symfony\Contracts\HttpClient\Exception\RedirectionExceptionInterface;
+use Symfony\Contracts\HttpClient\Exception\ServerExceptionInterface;
+use Symfony\Contracts\HttpClient\Exception\TransportExceptionInterface;
 
 #[Route(path: '/admin/ajax/device', name: 'ajax_device_')]
 class DeviceController extends Controller
@@ -80,6 +87,76 @@ class DeviceController extends Controller
 
     }
 
+	/**
+	 * @throws Exception
+	 */
+	#[Route(path: '/get/all-not-config-profile-assigned/{configProfileId}', name: 'get_all_not_config_profile_assigned', methods: ['GET'])]
+	public function getAllNotConfigProfileAssigned(Request          $request,
+													  DeviceRepository $deviceRepository,
+													  int $configProfileId): Response {
+
+		if ($request->isXmlHttpRequest()) {
+
+			$devices = $deviceRepository->findAllNotConfigProfileAssignedPlainSql($configProfileId);
+
+			$result = [];
+
+			foreach ($devices as $device) {
+				$result[$device['id_device']] = ['value' => $device['devid'], 'description' => $device['name']];
+			}
+
+			return new JsonResponse($result);
+		}
+
+		return new Response('Bad request.', 400);
+
+	}
+
+	/**
+	 * @throws Exception
+	 */
+	#[Route(path: '/get/all-with-configuration-profile', name: 'get_all_with_config_profile', methods: ['GET'])]
+	public function getAllDevicesWithAutomaticProfile(Request          $request,
+												   DeviceRepository $deviceRepository): Response {
+
+		if ($request->isXmlHttpRequest()) {
+
+			$devices = $deviceRepository->getDevicesToAssignConfigurationProfile();
+
+			$result = [];
+
+			foreach ($devices as $device) {
+				$result[$device['id_device']] = ['value' => $device['devid'], 'description' => $device['name']];
+			}
+
+			return new JsonResponse($result);
+		}
+
+		return new Response('Bad request.', 400);
+
+	}
+
+	#[Route(path: '/get/all-to-copy-configuration-profile', name: 'get_all_to_copy_config_profile', methods: ['GET'])]
+	public function getAllDevicesToCopyProfile(Request          $request,
+													  ConfigProfileRepository $configProfileRepository): Response {
+
+		if ($request->isXmlHttpRequest()) {
+
+			$profiles = $configProfileRepository->getProfilesToMakeCopy();
+
+			$result = [];
+
+			foreach ($profiles as $profile) {
+				$result[$profile['id']] = ['value' => $profile['name']/*, 'description' => $profile['name']*/];
+			}
+
+			return new JsonResponse($result);
+		}
+
+		return new Response('Bad request.', 400);
+
+	}
+
     /**
      * @param Request $request
      * @param ManagerRegistry $managerRegistry
@@ -258,7 +335,7 @@ class DeviceController extends Controller
 
             }
 
-            return new JsonResponse(['code' => "200", 'message' => 'Label was successfully assigned to the devices.', 'errors' => ['errors' => ['']]],
+            return new JsonResponse(['code' => "200", 'message' => 'Custom Label was successfully assigned to the devices.', 'errors' => ['errors' => ['']]],
                 200);
 
         }
@@ -269,12 +346,87 @@ class DeviceController extends Controller
 
     }
 
-    /**
-     * Add Fsw to Devices
-     * @param Request $request
-     * @param ManagerRegistry $managerRegistry
-     * @return Response
-     */
+	/**
+	 * Add System Labels to Devices
+	 * @param Request $request
+	 * @param ManagerRegistry $managerRegistry
+	 * @return Response
+	 */
+	#[Route(path: '/add/system-label', name: 'add_system_label', methods: ['POST'])]
+	public function addSystemLabelToDeviceAction(Request $request, ManagerRegistry $managerRegistry): Response {
+
+		if (!$request->isXmlHttpRequest()) {
+
+			return new Response('Bad request.', 400);
+
+		}
+
+		if (isset($request->request)) {
+
+			$labelIds = (array)$request->get('labels');
+			$selectedDevices = $request->get('selectedDevices');
+
+			if (!isset($labelIds) || !isset($selectedDevices))
+				return new JsonResponse(['status' => 'Error'], 400);
+
+			$deviceIds = [];
+
+			foreach ($selectedDevices as $device) {
+				$deviceIds[] = $device['id'];
+			}
+
+			$placeholders = [];
+			$values = [];
+			$types = [];
+
+			foreach ($deviceIds as $deviceId) {
+
+				foreach ($labelIds as $labelId) {
+					$placeholders[] = '(?)';
+					$values[] = [$labelId, $deviceId];
+					$types[] = ArrayParameterType::INTEGER;
+				}
+
+			}
+
+			/** @var Connection $connection */
+			$connection =  $managerRegistry->getConnection();
+
+			try{
+
+				$connection->executeStatement(
+					'INSERT IGNORE `system_labels_map` (`id_system_label`, `id_device`)  VALUES ' .
+					implode(', ', $placeholders),
+					$values,
+					$types
+				);
+
+			}catch (\Exception $e){
+
+				//dump($e->getMessage());
+
+				return new JsonResponse(['status' => 'Error', 'message' => 'Something bad happened.'],
+					400);
+
+			}
+
+			return new JsonResponse(['code' => "200", 'message' => 'System Label was successfully assigned to the devices.', 'errors' => ['errors' => ['']]],
+				200);
+
+		}
+
+		// If we reach this point, it means that something went wrong
+		return new JsonResponse(['status' => 'Error', 'message' => 'Something bad happened.'],
+			400);
+
+	}
+
+	/**
+	 * @param Request $request
+	 * @param ManagerRegistry $managerRegistry
+	 * @return Response
+	 * @throws Exception
+	 */
     #[Route(path: '/add/fw', name: 'add_fw', methods: ['POST'])]
     public function addFwToDeviceAction(Request $request, ManagerRegistry $managerRegistry): Response {
 
@@ -466,25 +618,24 @@ class DeviceController extends Controller
 
     }
 
-    /**
-     * @param Request $request
-     * @param DeviceRepository $deviceRepository
-     * @param ManagerRegistry $managerRegistry
-     * @return Response
-     * @throws Exception
-     */
+	/**
+	 * @param Request $request
+	 * @param ConfigProfileRepository $configProfileRepository
+	 * @return Response
+	 * @throws Exception
+	 */
     #[Route(path: '/get/config-profiles', name: 'get_config_profiles', methods: ['GET'])]
-    public function getConfigProfilesAction(Request $request, DeviceRepository $deviceRepository, ManagerRegistry $managerRegistry): Response
+    public function getConfigProfilesAction(Request $request, ConfigProfileRepository $configProfileRepository): Response
     {
 
         if ($request->isXmlHttpRequest()) {
 
-            $devices = $deviceRepository->getDevicesToClonedFrom();
+            $configProfiles = $configProfileRepository->getConfigProfilesToAssign();
 
             $result = [];
 
-            foreach ($devices as $device) {
-                $result[$device['id_device']] = ['value' => $device['devid'], 'description' => $device['name']];
+            foreach ($configProfiles as $profile) {
+                $result[$profile['id']] = ['value' => $profile['id'], 'description' => $profile['name']];
             }
 
             return new JsonResponse($result);
@@ -529,7 +680,7 @@ class DeviceController extends Controller
      * @throws Exception
      */
     #[Route(path: '/add/config-profile', name: 'add_config_profile', methods: ['POST'])]
-    public function addConfigProfileToDeviceAction(Request $request, ManagerRegistry $managerRegistry): Response {
+    public function addConfigProfileToDeviceAction(Request $request, ManagerRegistry $managerRegistry, ConfigProfiles $configProfilesApi): Response {
 
         if (!$request->isXmlHttpRequest()) {
 
@@ -539,18 +690,18 @@ class DeviceController extends Controller
 
         if (isset($request->request)) {
 
-            $devices = (array)$request->get('devices');
+            $profiles = $request->get('profiles');
             $selectedDevices = $request->get('selectedDevices');
-            $overwrite = $request->get('overwrite'); //retype to bool did not work for false
+            $overwrite = $request->get('overwrite', 'false'); //retype to bool did not work for false
 
-            if (!isset($devices) && !isset($selectedDevices)) {
+            if (!isset($profiles) && !isset($selectedDevices)) {
 				return new JsonResponse(['status' => 'Error'], 400);
 			}
 
-            $devices = $managerRegistry->getRepository(Device::class)->findBy(['id' => $devices]);
-            $deviceRepository = $managerRegistry->getRepository(Device::class);
+			$profiles = $managerRegistry->getRepository(ConfigProfile::class)->findBy(['id' => $profiles]);
+			$deviceRepository = $managerRegistry->getRepository(Device::class);
 
-			if (!$devices){
+			if (!$profiles){
 				return new JsonResponse(['status' => 'Error'], 400);
 			}
 
@@ -559,13 +710,36 @@ class DeviceController extends Controller
 
             foreach ($selectedDevices as $device) {
 
-                $device = $deviceRepository->findOneBy(['id' => $device['id']]);
+				$device = $deviceRepository->findOneBy(['id' => $device['id']]);
 
-                $deviceType = $device->getDevType();
+				if(!$device){
+					$errors[] = $device->getDevId();
+					continue;
+				}
 
-                foreach ($devices as $deviceCloneFrom) {
+				$deviceTypeId = $device->getDevType()->getId();
+				if($deviceTypeId !== DeviceType::DEVICE_TYPE_ADVANTECH_ROUTER_ID){
+					//skip non Advantech devices
+					$errors[] = $device->getDevId();
+					continue;
+				}
 
-                    $deviceTypeCloneFrom = $deviceCloneFrom->getDevType();
+				if ( ($device->getConfigProfile() instanceof ConfigProfile && $overwrite === 'false')) {
+					//skip assign already assigned profiles when not overwrite is true
+					$errors[] = $device->getDevId();
+					continue;
+				}
+
+                foreach ($profiles as $profile) {
+
+					try{
+						$configProfilesApi->assignDeviceToConfigProfile($profile->getId(), [$device->getId()]);
+						$success[] = $device->getDevId();
+					}catch (\Exception $exception){
+						$errors[] = $profile->getDevId();
+					}
+
+                    /*$deviceTypeCloneFrom = $deviceCloneFrom->getDevType();
                     $deviceConfigProfileFrom = $deviceCloneFrom->getConfigProfileAutomatic();
 
                     //Check if there is the same OS type on device as selected FW
@@ -580,39 +754,12 @@ class DeviceController extends Controller
 
                         $errors[] = $device->getDevId();
 
-                    }
+                    }*/
 
                 }
 
             }
 
-            /** @var Connection $connection */
-            $connection =  $managerRegistry->getConnection();
-
-            try{
-
-                $connection->beginTransaction();
-
-                $globalVersion = $connection->executeQuery('SELECT `version` FROM `product_flags` WHERE `id` = "user_devchg_version"')->fetchOne();
-                $connection->executeQuery('UPDATE `product_flags` SET `version` = `version` + 1 WHERE `id` = "user_devchg_version"')->fetchOne();
-                $connection->executeStatement('UPDATE `device_stats` SET `sync` = 2 WHERE `id_device` IN (?)', [$values], [ArrayParameterType::INTEGER]);
-
-                $connection->executeStatement(
-                    'UPDATE `devices` SET `config_profile` = ?, `gui_version` = ?  WHERE `id_device` IN (?)',
-                    [$deviceConfigProfileFrom->getId(), $globalVersion + 1,  $values],
-                    [ParameterType::INTEGER, ParameterType::INTEGER, ArrayParameterType::INTEGER]
-                );
-
-                $connection->commit();
-
-            }catch (\Exception $e){
-
-                $connection->rollback();
-
-                return new JsonResponse(['status' => 'Error', 'message' => $e->getMessage()],
-                    400);
-            }
-
             return new JsonResponse([
                 'code' => 200,
                 'message' => 'Config Profile was successfully assigned to the devices: ',
@@ -629,15 +776,167 @@ class DeviceController extends Controller
 
     }
 
-    /**
-     * @param Request $request
-     * @param ManagerRegistry $managerRegistry
-     * @param DeviceRepository $deviceRepository
-     * @return Response
-     */
+	/**
+	 * @param Request $request
+	 * @param ManagerRegistry $managerRegistry
+	 * @return Response
+	 */
+	#[Route(path: '/remove/custom-label', name: 'remove_custom_label', methods: ['POST'])]
+	public function removeCustomLabelDeviceAction(Request $request, ManagerRegistry $managerRegistry): Response
+	{
+
+		if (!$request->isXmlHttpRequest()) {
+
+			return new Response('Bad request.', 400);
+
+		}
+
+		if (isset($request->request)) {
+
+			$labelIds = (array)$request->get('labels');
+			$selectedDevices = $request->get('selectedDevices');
+
+			if (!isset($labelIds) || !isset($selectedDevices))
+				return new JsonResponse(['status' => 'Error'], 400);
+
+			$errors = [];
+			$success = [];
+
+			$deviceIds = [];
+
+			foreach ($selectedDevices as $device) {
+				$deviceIds[] = $device['id'];
+			}
+
+			$placeholders = [];
+			$values = [];
+			$types = [];
+
+			foreach ($deviceIds as $deviceId) {
+
+				foreach ($labelIds as $labelId) {
+					$placeholders[] = '(id_label = ? AND id_device = ?)';
+					$values[] = [$labelId];
+					$values[] = [$deviceId];
+					$types[] = ArrayParameterType::INTEGER;
+					$types[] = ArrayParameterType::INTEGER;
+				}
+			}
+
+			/** @var Connection $connection */
+			$connection =  $managerRegistry->getConnection();
+
+			try{
+
+				$connection->executeStatement(
+					'DELETE FROM `labels_map` WHERE ' . implode(' OR ', $placeholders),
+					$values,
+					$types
+				);
+
+			}catch (\Exception $e){
+
+				return new JsonResponse(['status' => 'Error', 'message' => 'Something bad happened.'],
+					400);
+
+			}
+
+			return new JsonResponse(['code' => "200", 'message' => 'Custom Labels was successfully removed from the devices.', 'errors' => ['errors' => ['']]],
+				200);
+
+		}
+
+		return new JsonResponse(['status' => 'Error', 'message' => 'Something bad happened.'],
+			400);
+
+	}
+
+	/**
+	 * @param Request $request
+	 * @param ManagerRegistry $managerRegistry
+	 * @return Response
+	 */
+	#[Route(path: '/remove/system-label', name: 'remove_system_label', methods: ['POST'])]
+	public function removeSystemLabelDeviceAction(Request $request, ManagerRegistry $managerRegistry): Response
+	{
+
+		if (!$request->isXmlHttpRequest()) {
+
+			return new Response('Bad request.', 400);
+
+		}
+
+		if (isset($request->request)) {
+
+			$labelIds = (array)$request->get('labels');
+			$selectedDevices = $request->get('selectedDevices');
+
+			if (!isset($labelIds) || !isset($selectedDevices))
+				return new JsonResponse(['status' => 'Error'], 400);
+
+			$errors = [];
+			$success = [];
+
+			$deviceIds = [];
+
+			foreach ($selectedDevices as $device) {
+				$deviceIds[] = $device['id'];
+			}
+
+			$placeholders = [];
+			$values = [];
+			$types = [];
+
+			foreach ($deviceIds as $deviceId) {
+
+				foreach ($labelIds as $labelId) {
+					$placeholders[] = '(id_system_label = ? AND id_device = ?)';
+					$values[] = [$labelId];
+					$values[] = [$deviceId];
+					$types[] = ArrayParameterType::INTEGER;
+					$types[] = ArrayParameterType::INTEGER;
+				}
+			}
+
+			/** @var Connection $connection */
+			$connection =  $managerRegistry->getConnection();
+
+			try{
+
+				$connection->executeStatement(
+					'DELETE FROM `system_labels_map` WHERE ' . implode(' OR ', $placeholders),
+					$values,
+					$types
+				);
+
+			}catch (\Exception $e){
+
+				return new JsonResponse(['status' => 'Error', 'message' => 'Something bad happened.'],
+					400);
+
+			}
+
+			return new JsonResponse(['code' => "200", 'message' => 'System Labels was successfully removed from the devices.', 'errors' => ['errors' => ['']]],
+				200);
+
+		}
+
+		return new JsonResponse(['status' => 'Error', 'message' => 'Something bad happened.'],
+			400);
+
+	}
+
+	/**
+	 * @param Request $request
+	 * @param ConfigProfiles $configProfilesApi
+	 * @return Response
+	 * @throws ClientExceptionInterface
+	 * @throws RedirectionExceptionInterface
+	 * @throws ServerExceptionInterface
+	 * @throws TransportExceptionInterface
+	 */
     #[Route(path: '/remove/config-profile', name: 'remove_config_profile', methods: ['POST'])]
-    public function removeConfigProfileDeviceAction(Request $request, ManagerRegistry $managerRegistry,
-                                                    DeviceRepository $deviceRepository): Response
+    public function removeConfigProfileDeviceAction(Request $request, ConfigProfiles $configProfilesApi): Response
     {
 
         if (!$request->isXmlHttpRequest()) {
@@ -650,8 +949,9 @@ class DeviceController extends Controller
 
             $selectedDevices = $request->get('selectedDevices');
 
-            if (!isset($selectedDevices))
-                return new JsonResponse(['status' => 'Error'], 400);
+            if (!isset($selectedDevices)) {
+				return new JsonResponse(['status' => 'Error'], 400);
+			}
 
             $errors = [];
             $success = [];
@@ -662,42 +962,22 @@ class DeviceController extends Controller
                 $deviceIds[] = $device['id'];
             }
 
-            $connection =  $managerRegistry->getConnection();
+			try{
 
-            try{
+				$configProfilesApi->unassignDeviceFromConfigProfile($deviceIds);
 
-                $connection->beginTransaction();
+			}catch (\Exception $exception){
+				return new JsonResponse(['status' => 'Error', 'errors' => $exception->getMessage()], 200);
+			}
 
-                $globalVersion = $connection->executeQuery('SELECT `version` FROM `product_flags` WHERE `id` = "user_devchg_version"')->fetchOne();
-                $connection->executeQuery('UPDATE `product_flags` SET `version` = `version` + 1 WHERE `id` = "user_devchg_version"')->fetchOne();
-                $connection->executeStatement('UPDATE `device_stats` SET `sync` = 2 WHERE `id_device` IN (?)', [$deviceIds], [ArrayParameterType::INTEGER]);
-
-
-                $connection->executeStatement(
-                    'UPDATE `devices` SET `config_profile` = ?, `gui_version` = ?  WHERE `id_device` IN (?)',
-                    [null, $globalVersion + 1,  $deviceIds],
-                    [ParameterType::INTEGER, ParameterType::INTEGER, ArrayParameterType::INTEGER]
-                );
-
-                $connection->commit();
-
-            }catch (\Exception $e){
-
-                $connection->rollback();
-
-                return new JsonResponse(['status' => 'Error', 'message' => 'Something bad happened.'],
-                    400);
-            }
-
-            return new JsonResponse([
-                'code' => 200,
-                'message' => 'Config Profile was successfully removed for selected devices.',
-                'success' => $success,
-                'errors' => $errors
-            ],
-                200);
+			return new JsonResponse(['code' => 200, 'message' => 'Devices successfully unassigned from the Config profile.',
+				'errors' => ['errors' => ['']]],
+				200);
 
         }
+
+		return new JsonResponse(['status' => 'Error', 'message' => 'Something bad happened.'],
+			400);
     }
 
     #[Route(path: '/reboot/{deviceId}', name: 'reboot', methods: ['GET'])]
