@@ -401,7 +401,8 @@ class DeviceController extends BaseController
 
         $osVersions = $managerRegistry->getRepository(DeviceOsVersion::class)->findBy($findBy, ['version' => 'DESC']);
 
-        $clonedFromDeviceId = (!empty($device->getConfigProfile())) ? $device->getConfigProfile()->getAutomatic()->getId() : null;
+
+        $clonedFromDeviceId = (!empty($device->getConfigProfileAutomatic()->getAutomatic())) ? $device->getConfigProfileAutomatic()->getAutomatic()->getId() : null;
         $devicesToCloneToExcludeDeviceIds = [$device->getId()];
         if (isset($clonedFromDeviceId)) {
             $devicesToCloneToExcludeDeviceIds[] = $clonedFromDeviceId;
