@@ -105,27 +105,45 @@ class ConfigProfileDatatable extends BaseDatatable
                 'width' => '100%;',
                 'actions' => [
 
-                    [
-                        'route' => 'ajax_config_profile_download',
-                        'route_parameters' => [
-                            'configProfileId' => 'id',
-                            ],
-                        'label' => $this->translator->trans('sg.datatables.actions.download'),
-                        'icon' => self::ICON_DOWNLOAD,
-                        'attributes' => [
-                            'rel' => 'tooltip',
-                            'title' => $this->translator->trans('sg.datatables.actions.download'),
+					[
+						'route' => 'admin_config_profile_manage',
+						'route_parameters' => [
+							'configProfileId' => 'id',
+						],
+						'label' => $this->translator->trans('sg.datatables.actions.manage'),
+						'icon' => self::ICON_MANAGE,
+						'attributes' => [
+							'rel' => 'tooltip',
+							'title' => $this->translator->trans('sg.datatables.actions.manage'),
 							'class' => 'btn btn-primary btn-xs mb-1 mr-sm-2',
-                            'role' => 'button',
-                            'data-toggle' => 'modal',
-							'data-target' => '#confirm-download-modal',
-                            'id' => 'download',
-                        ],
+							'role' => 'button',
+							'id' => 'manage',
+						],
 						'start_html' => '<div class="input-group">',
-                        'render_if' => function ($row) {
-                            return $this->authorizationChecker->isGranted('ROLE_ADMIN');
-                        },
-                    ],
+						'render_if' => function ($row) {
+							return $this->authorizationChecker->isGranted('ROLE_ADMIN');
+						},
+					],
+
+					[
+						'route' => 'admin_config_profile_assign_device',
+						'route_parameters' => [
+							'configProfileId' => 'id',
+						],
+						'label' => $this->translator->trans('sg.datatables.actions.devices'),
+						'icon' => self::ICON_DETAIL,
+						'attributes' => [
+							'rel' => 'tooltip',
+							'title' => $this->translator->trans('sg.datatables.actions.devices'),
+							'class' => 'btn btn-primary btn-xs mb-1 mr-sm-2',
+							'role' => 'button',
+							'id' => 'devices',
+						],
+						'start_html' => '<div class="input-group">',
+						'render_if' => function ($row) {
+							return $this->authorizationChecker->isGranted('ROLE_ADMIN');
+						},
+					],
 
 					[
 						'route' => 'ajax_config_profile_delete',
