@@ -36,7 +36,7 @@ class DeviceDatatable extends BaseDatatable
     public const availableColumns = ['devId' => 'DevId', 'name' => 'Name', 'devTypeName' => 'Type', 'SnpmDevTypeName' => 'SNMP subtype',
         'OsVerOsTypeName' => "OS", 'OsVerVersion' => 'Version', 'Labels' => 'Labels', 'SystemLabels' => 'System Labels',
         'IpAddresses' => 'Ip Addresses', 'MonitoringGroups' => 'MonitoringGroups',
-        'ConfigProfileAutomaticDevId' => 'Cloned From', 'StatsSyncStatusDescription' => 'Sync Status',
+        'ConfigProfile' => 'Config profile', 'StatsSyncStatusDescription' => 'Sync Status',
         'StatLiveMissCountDescription' => 'Freshness', 'SerialNumber' => 'Serial Number',
         'MacAddress' => 'Mac Address', self::tableColumnName_SnmpName => self::username_SnmpName,
         'Model' => 'Model', 'HostName' => 'Host Name', 'Uuid' => 'UuId',
@@ -65,6 +65,7 @@ class DeviceDatatable extends BaseDatatable
     protected array $deviceLabels;
     protected array $deviceSystemLabels;
     protected array $deviceMonitoringGroups;
+    protected array $configProfiles;
     protected array $agentProfiles;
     protected array $authProfiles;
     protected array $columns;
@@ -179,6 +180,7 @@ class DeviceDatatable extends BaseDatatable
         $this->deviceSystemLabels = $options['deviceSystemLabels'];
         $this->deviceSimCards = $options['deviceSimCards'];
         $this->deviceMonitoringGroups = $options['deviceMonitoringGroups'];
+		$this->configProfiles = $options['configProfiles'];
         $this->agentProfiles = $options['agentProfiles'];
         $this->authProfiles = $options['authProfiles'];
         $this->models = $options['models'];
@@ -780,7 +782,7 @@ class DeviceDatatable extends BaseDatatable
 
     private function getColumnModel(): void
     {
-        $this->addDefaultSelectableFilterColumns('modelDevice.model', 'Model', $this->getOptionsArrayFromEntities($this->models, 'model', 'model'));
+        $this->addDefaultSelectableFilterColumns('model.model', 'Model', $this->getOptionsArrayFromEntities($this->models, 'model', 'model'));
     }
 
     private function getColumnSnmpname(): void
@@ -861,28 +863,28 @@ class DeviceDatatable extends BaseDatatable
 		$this->addDefaultTextColumn('stats.simIp6addr', 'SIM IPv6');
 	}
 
-    private function getColumnConfigProfileAutomaticDevId(): void
+    private function getColumnConfigProfile(): void
     {
 
         $this->columnBuilder->add(
-            'configProfile.automatic.devId',
+            'configProfile.name',
             LinkColumn::class,
             [
-                'name' => 'clonedFrom',
-                'title' => 'Cloned from',
+                'name' => 'configProfile',
+                'title' => 'Config profile',
                 'default_content' => '',
                 'width' => '100%;',
-                'route' => 'admin_devices_detail',
+                'route' => 'admin_config_profile_manage',
                 'route_params' => function ($row) {
                     return [
-                        'deviceId' => $row['configProfile']['automatic']['id'],
+                        'configProfileId' => $row['configProfile']['id'],
                     ];
                 },
                 'filter' => [
                     SelectFilter::class,[
                         'search_type' => 'eq',
                         'select_options' => ['' => 'Any']
-                            + $this->getOptionsFromArray($this->devices, 'devid', 'devid'),
+                            + $this->getOptionsArrayFromEntities($this->configProfiles, 'name', 'name'),
                         'cancel_button' => true,
                     ],
                 ],
