@@ -16,6 +16,9 @@ use Doctrine\ORM\Mapping as ORM;
 #[ORM\Entity]
 class ConfigProfile
     {
+
+	final public const ENTITY_TABLE_NAME = 'config_profiles';
+
     /**
 	 *
      * @var int|null
@@ -29,14 +32,14 @@ class ConfigProfile
      * @var string
      */
     #[ORM\Column(type: Types::STRING, length: 64, nullable: true)]
-    public string $name;
+    public ?string $name;
 
-    /**
-     * @var Device
-     */
-    #[ORM\OneToOne(inversedBy: 'configProfileAutomatic', targetEntity: Device::class, cascade: ['persist'])]
+	/**
+	 * @var Device|null
+	 */
+    #[ORM\OneToOne(targetEntity: Device::class, inversedBy: 'configProfileAutomatic', cascade: ['persist'])]
     #[ORM\JoinColumn(name: 'automatic', referencedColumnName: 'id_device', nullable: true)]
-    public Device $automatic;
+    public ?Device $automatic;
 
     /**
      * @var bool
@@ -73,7 +76,7 @@ class ConfigProfile
     /**
      * @var Collection
      */
-    #[ORM\OneToMany(mappedBy: 'configProfile', targetEntity: Device::class, cascade: ['persist'])]
+    #[ORM\OneToMany(targetEntity: Device::class, mappedBy: 'configProfile', cascade: ['persist'])]
     #[ORM\JoinColumn(name: 'id', referencedColumnName: 'id')]
     public Collection $devices;
 
@@ -95,15 +98,24 @@ class ConfigProfile
 
     }
 
-    /**
-     * @return string
-     */
+	/**
+	 * @return string|null
+	 */
     public function getName(): ?string {
 
         return $this->name;
 
     }
 
+	/**
+	 * @param string|null $name
+	 * @return void
+	 */
+	public function setName(?string $name): void
+	{
+		$this->name = $name;
+	}
+
     /**
      * @return Device
      */
