@@ -28,7 +28,7 @@ class DeviceModel {
     /**
      * @var Device
      */
-    #[ORM\OneToOne(inversedBy: 'modelDevice', targetEntity: Device::class)]
+    #[ORM\OneToOne(targetEntity: Device::class, inversedBy: 'model')]
     #[ORM\JoinColumn(name: 'id', referencedColumnName: 'id_device', nullable: true)]
     public Device $device;
 
@@ -39,4 +39,12 @@ class DeviceModel {
         return $this->id;
     }
 
+	/**
+	 * @return string|null
+	 */
+	public function getModel(): ?string
+	{
+		return $this->model;
+	}
+
 }
