@@ -4,6 +4,7 @@ declare(strict_types=1);
 
 namespace App\Entity\Device;
 
+use Doctrine\DBAL\Types\Types;
 use Doctrine\ORM\Mapping as ORM;
 
 #[ORM\Table(name: 'device_notes')]
@@ -13,7 +14,7 @@ class DeviceNote {
     /**
      * @var int|null
      */
-    #[ORM\Column(type: 'integer')]
+    #[ORM\Column(type: Types::INTEGER)]
     #[ORM\Id]
     #[ORM\GeneratedValue(strategy: 'AUTO')]
     private ?int $idDevice = null;
@@ -21,25 +22,25 @@ class DeviceNote {
     /**
      * @var string|null
      */
-    #[ORM\Column(type: 'string', length: 64, nullable: true)]
+    #[ORM\Column(type: Types::STRING, length: 64, nullable: true)]
     public ?string $note1 = null;
 
     /**
      * @var string|null
      */
-    #[ORM\Column(type: 'string', length: 64, nullable: true)]
+    #[ORM\Column(type: Types::STRING, length: 64, nullable: true)]
     public ?string $note2 = null;
 
     /**
      * @var string|null
      */
-    #[ORM\Column(type: 'string', length: 64, nullable: true)]
+    #[ORM\Column(type: Types::STRING, length: 64, nullable: true)]
     public ?string $note3 = null;
 
     /**
      * @var Device
      */
-    #[ORM\OneToOne(targetEntity: Device::class, inversedBy: 'noteDevice')]
+    #[ORM\OneToOne(inversedBy: 'noteDevice', targetEntity: Device::class)]
     #[ORM\JoinColumn(name: 'id_device', referencedColumnName: 'id_device', nullable: true)]
     public Device $device;
 
