@@ -180,9 +180,9 @@ class VDevice
     /**
      * @var DeviceModel|null
      */
-    #[ORM\OneToOne(mappedBy: 'device', targetEntity: DeviceModel::class, cascade: ['persist'])]
-    #//[ORM\JoinColumn(name: 'model')]
-    public ?DeviceModel $modelDevice = null;
+	#[ORM\OneToOne(targetEntity: DeviceModel::class, cascade: ['persist'])]
+	#[ORM\JoinColumn(name: 'model', referencedColumnName: 'id')]
+	public ?DeviceModel $model = null;
 
     /**
      * @var DeviceCustomField|null
@@ -522,11 +522,13 @@ class VDevice
     /**
      * @return DeviceModel|null
      */
-    public function getModelDevice(): ?DeviceModel
+    public function getModel(): ?DeviceModel
     {
-        return $this->modelDevice;
+        return $this->model;
     }
 
+
+
     /**
      * @return Collection
      */
