@@ -6,6 +6,7 @@ namespace App\Entity\EventLog;
 
 use Doctrine\Common\Collections\ArrayCollection;
 use Doctrine\Common\Collections\Collection;
+use Doctrine\DBAL\Types\Types;
 use Doctrine\ORM\Mapping as ORM;
 
 #[ORM\Table(name: 'log_event_source')]
@@ -19,7 +20,7 @@ class EventSource
     /**
      * @var int|null
      */
-    #[ORM\Column(type: 'integer')]
+    #[ORM\Column(type: Types::INTEGER)]
     #[ORM\Id]
     #[ORM\GeneratedValue(strategy: 'AUTO')]
     private ?int $id = null;
@@ -27,13 +28,13 @@ class EventSource
     /**
      * @var string
      */
-    #[ORM\Column(type: 'string', length: 32, unique: true, nullable: false)]
+    #[ORM\Column(type: Types::STRING, length: 32, unique: true, nullable: false)]
     public string $name;
 
     /**
      * @var Collection
      */
-    #[ORM\OneToMany(mappedBy: 'source', targetEntity: EventLog::class, cascade: ['persist'])]
+    #[ORM\OneToMany(targetEntity: EventLog::class, mappedBy: 'source', cascade: ['persist'])]
     #[ORM\JoinColumn(name: 'id')]
     public Collection $events;
 
