@@ -6,6 +6,7 @@ namespace App\Entity\Label;
 
 use Doctrine\Common\Collections\ArrayCollection;
 use Doctrine\Common\Collections\Collection;
+use Doctrine\DBAL\Types\Types;
 use Doctrine\ORM\Mapping as ORM;
 
 #[ORM\Table(name: 'system_labels')]
@@ -15,7 +16,7 @@ class SystemLabel
     /**
      * @var int|null
      */
-    #[ORM\Column(type: 'integer')]
+    #[ORM\Column(type: Types::INTEGER)]
     #[ORM\Id]
     #[ORM\GeneratedValue(strategy: 'AUTO')]
     private ?int $id = null;
@@ -23,19 +24,19 @@ class SystemLabel
     /**
      * @var string
      */
-    #[ORM\Column(type: 'string', length: 64, unique: true, nullable: false)]
+    #[ORM\Column(type: Types::STRING, length: 64, unique: true, nullable: false)]
     public string $label;
 
     /**
      * @var string
      */
-    #[ORM\Column(type: 'text', nullable: true)]
+    #[ORM\Column(type: Types::TEXT, nullable: true)]
     public string $description;
 
     /**
      * @var Collection
      */
-    #[ORM\OneToMany(mappedBy: 'systemLabel', targetEntity: SystemLabelDeviceMap::class, cascade: ['persist', 'remove'])]
+    #[ORM\OneToMany(targetEntity: SystemLabelDeviceMap::class, mappedBy: 'systemLabel', cascade: ['persist', 'remove'])]
     #[ORM\JoinColumn(name: 'id')]
     public Collection $devices;
 
