@@ -5,6 +5,7 @@ declare(strict_types=1);
 namespace App\Entity\Tunnel;
 
 use App\Entity\Tunnel;
+use Doctrine\DBAL\Types\Types;
 use Doctrine\ORM\Mapping as ORM;
 
 #[ORM\Table(name: 'tunnel_op_status_map')]
@@ -14,7 +15,7 @@ class TunnelOperationStatusMapping
     /**
      * @var int|null
      */
-    #[ORM\Column(type: 'integer')]
+    #[ORM\Column(type: Types::INTEGER)]
     #[ORM\Id]
     #[ORM\GeneratedValue(strategy: 'AUTO')]
     private ?int $id = null;
