@@ -2,7 +2,7 @@
 
 namespace App\Form;
 
-use App\Entity\MonitoringGroup;
+use App\Entity\MonitoringGroup\MonitoringGroup;
 use Symfony\Component\Form\AbstractType;
 use Symfony\Component\Form\Extension\Core\Type\SubmitType;
 use Symfony\Component\Form\Extension\Core\Type\TextType;
