@@ -5,9 +5,12 @@ namespace App\Repository;
 use App\Entity\Device\Device;
 use App\Entity\Device\DeviceStats;
 use App\Entity\Device\DeviceSyncStatus;
+use App\Entity\Device\DeviceOsVersion;
 use App\Entity\MonitoringGroup\MonitoringGroupMapping;
 use App\Entity\Tunnel\Tunnels;
 use Doctrine\Bundle\DoctrineBundle\Repository\ServiceEntityRepository;
+use Doctrine\DBAL\ArrayParameterType;
+use Doctrine\DBAL\Connection;
 use Doctrine\DBAL\Exception;
 use Doctrine\DBAL\ParameterType;
 use Doctrine\ORM\Query;
@@ -81,7 +84,7 @@ class DeviceRepository extends ServiceEntityRepository
             ORDER BY devid
             ';
 
-        return $conn->executeQuery($sql, array('deviceIds' => $deviceIds, 'devTypeId' => $devTypeId), ['deviceIds' => \Doctrine\DBAL\Connection::PARAM_INT_ARRAY])->fetchAllAssociative();
+        return $conn->executeQuery($sql, array('deviceIds' => $deviceIds, 'devTypeId' => $devTypeId), ['deviceIds' => Connection::PARAM_INT_ARRAY])->fetchAllAssociative();
 
     }
 
@@ -197,6 +200,21 @@ class DeviceRepository extends ServiceEntityRepository
 
     }
 
+	/**
+	 * @throws Exception
+	 */
+	public function findAllNotConfigProfileAssignedPlainSql(int $configProfileId): array {
+
+		$conn = $this->getEntityManager()->getConnection();
+
+		$sql = "SELECT id_device, devid, name
+                    FROM ". Device::ENTITY_TABLE_NAME ."
+                    WHERE (config_profile != :configProfileId OR config_profile is null) AND deleted = 0";
+
+		return $conn->executeQuery($sql, ['configProfileId' => $configProfileId], ['mntGroupId' => \PDO::PARAM_INT])->fetchAllAssociative();
+
+	}
+
     /**
      * @return array
      * @throws Exception
@@ -346,7 +364,7 @@ class DeviceRepository extends ServiceEntityRepository
             WHERE id_device IN (?) 
             ';
 
-        return $conn->executeQuery($sql, array($devicesId), array(\Doctrine\DBAL\Connection::PARAM_INT_ARRAY))->fetchAllAssociative();
+        return $conn->executeQuery($sql, array($devicesId), array(ArrayParameterType::INTEGER))->fetchAllAssociative();
 
     }
 
@@ -371,7 +389,7 @@ class DeviceRepository extends ServiceEntityRepository
 
         return $conn->executeQuery($sql, array($configProfileId, DeviceSyncStatus::BEING_PROCESSED, $devicesId),
             array((is_int($configProfileId)) ? ParameterType::INTEGER : ParameterType::NULL,
-                ParameterType::INTEGER, \Doctrine\DBAL\Connection::PARAM_INT_ARRAY))->fetchAllAssociative();
+                ParameterType::INTEGER, ArrayParameterType::INTEGER))->fetchAllAssociative();
 
 
     }
@@ -390,7 +408,7 @@ class DeviceRepository extends ServiceEntityRepository
             WHERE d.automatic_profile is not null AND d.deleted = 0
             ';
 
-        return $conn->executeQuery($sql, [], ['deviceIds' => \Doctrine\DBAL\Connection::PARAM_INT_ARRAY])->fetchAllAssociative();
+        return $conn->executeQuery($sql, [], ['deviceIds' => ArrayParameterType::INTEGER])->fetchAllAssociative();
 
     }
 
@@ -405,9 +423,30 @@ class DeviceRepository extends ServiceEntityRepository
             WHERE d.automatic_profile is not null AND d.deleted = 0
             ';
 
-		return $conn->executeQuery($sql, [], ['deviceIds' => \Doctrine\DBAL\Connection::PARAM_INT_ARRAY])->fetchAllAssociative();
+		return $conn->executeQuery($sql, [], ['deviceIds' => ArrayParameterType::INTEGER])->fetchAllAssociative();
 
 
 	}
 
+	/**
+	 * @throws Exception
+	 */
+	public function getDevicesFwVersions(): array
+	{
+
+		$conn = $this->getEntityManager()->getConnection();
+
+		//search by id instead of description text addAndExpression function
+		// on SelectFilter to define what column to use for search
+		//SELECT dosv.id, dosv.description FROM '. Device::ENTITY_TABLE_NAME .' as d
+		$sql = '
+            SELECT dosv.description, dosv.description FROM '. Device::ENTITY_TABLE_NAME .' as d
+            INNER JOIN '. DeviceOsVersion::ENTITY_TABLE_NAME .' dosv ON dosv.id = d.os_ver
+            GROUP BY d.os_ver
+            ';
+
+		return $conn->executeQuery($sql)->fetchAllKeyValue();
+
+	}
+
 }
\ No newline at end of file
