@@ -2,21 +2,23 @@
 
 namespace App\Service;
 
-use App\Datatables\AlertDatatable;
-use App\Datatables\DeviceDatatable;
+use App\DataTable\AlertDatatable;
+use App\DataTable\DeviceDatatable;
 use App\Entity\AgentProfile\AgentProfile;
 use App\Entity\Alert\AlertTargetSpec;
 use App\Entity\Alert\AlertTargetType;
-use App\Entity\Device;
-use App\Entity\DeviceOsType;
-use App\Entity\DeviceSyncStatus;
-use App\Entity\DeviceType;
-use App\Entity\Label;
-use App\Entity\LivenessMisscount;
-use App\Entity\MonitoringGroup;
-use App\Entity\SystemLabel;
+use App\Entity\Device\Device;
+use App\Entity\Device\DeviceModel;
+use App\Entity\Device\DeviceOsType;
+use App\Entity\Device\DeviceOsVersion;
+use App\Entity\Device\DeviceSyncStatus;
+use App\Entity\Device\DeviceType;
+use App\Entity\Label\Label;
+use App\Entity\Label\SystemLabel;
+use App\Entity\MonitoringGroup\MonitoringGroup;
 use App\Entity\Tool\AuthProfile;
 use App\Entity\Tool\SimCard;
+use App\Entity\Types\LivenessMisscount;
 use App\Repository\DeviceRepository;
 use Doctrine\Persistence\ManagerRegistry;
 use Sg\DatatablesBundle\Datatable\DatatableFactory;
@@ -38,8 +40,7 @@ class DatatableService
      * @param ConfigurationService $configurationService
      */
     public function __construct(DatatableFactory $datatableFactory, ManagerRegistry $managerRegistry,
-                                ConfigurationService $configurationService,
-								DeviceRepository $deviceRepository){
+                                ConfigurationService $configurationService, DeviceRepository $deviceRepository){
 
         $this->datatableFactory = $datatableFactory;
         $this->managerRegistry = $managerRegistry;
@@ -68,6 +69,7 @@ class DatatableService
         $deviceMonitoringGroups = $this->managerRegistry->getRepository(MonitoringGroup::class)->findAll();
         $deviceAgentProfiles = $this->managerRegistry->getRepository(AgentProfile::class)->findAll();
         $deviceAuthProfiles = $this->managerRegistry->getRepository(AuthProfile::class)->findAll();
+        $deviceModels = $this->managerRegistry->getRepository(DeviceModel::class)->findAll();
         $devices = $this->managerRegistry->getRepository(Device::class)->getDevices();
         $deviceTableColumns = $this->configurationService->getDeviceTableColumns();
 
@@ -76,7 +78,7 @@ class DatatableService
             'osTypes' => $deviceOsType, 'osVersions' => $osVersions, 'deviceLabels' => $deviceLabels,
             'deviceSystemLabels' => $deviceSystemLabels, 'deviceSimCards' => $deviceSimCards,
             'deviceMonitoringGroups' => $deviceMonitoringGroups,
-            'agentProfiles' => $deviceAgentProfiles, 'authProfiles' => $deviceAuthProfiles,
+            'agentProfiles' => $deviceAgentProfiles, 'authProfiles' => $deviceAuthProfiles, 'models' => $deviceModels,
             'columns' => $deviceTableColumns]);
 
         $datatable = $this->datatableFactory->create($class);
